@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2022 BigML
+# Copyright 2012-2023 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -204,7 +204,7 @@ def file_number_of_lines(file_name):
 
     """
     try:
-        item = (0, None)
+        item = (-1, None)
         with open(file_name) as file_handler:
             for item in enumerate(file_handler):
                 pass
