@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-#
+#pylint: disable=locally-disabled,attribute-defined-outside-init
 # Auxiliar class: Simple stoppable HTTPServer extracted from
 #
 # http://code.activestate.com/recipes/425210-simple-stoppable-server-using-socket-timeout/
@@ -12,13 +12,16 @@ import http.server
 import socket
 
 class StoppableHTTPServer(http.server.HTTPServer):
+    """Basic stoppable HTTP server to show reports"""
 
     def server_bind(self):
+        """Binding the server """
         http.server.HTTPServer.server_bind(self)
         self.socket.settimeout(1)
         self.run = True
 
     def get_request(self):
+        """Get method"""
         while self.run:
             try:
                 sock, addr = self.socket.accept()
@@ -28,8 +31,10 @@ class StoppableHTTPServer(http.server.HTTPServer):
                 pass
 
     def stop(self):
+        """Stopper """
         self.run = False
 
     def serve(self):
+        """Serving """
         while self.run:
             self.handle_request()
