@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 #!/usr/bin/env python
+#pylint: disable=locally-disabled,line-too-long,attribute-defined-outside-init
 #
-# Copyright 2015-2022 BigML
+# Copyright 2015-2023 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,11 +20,8 @@
 """ Testing shared resources
 
 """
-
-
-
 from bigmler.tests.world import (world, common_setup_module,
-                                 common_teardown_module, teardown_class)
+                                 common_teardown_module, show_method)
 
 
 import bigmler.tests.basic_tst_prediction_steps as test_pred
@@ -41,21 +39,25 @@ def teardown_module():
     """
     common_teardown_module()
 
-class TestShared(object):
+class TestShared:
+    """Testing sharing resources """
 
-    def teardown(self):
-        """Calling generic teardown for every method
-
-        """
-        print("\nEnd of tests in: %s\n-------------------\n" % __name__)
-        teardown_class()
-
-    def setup(self):
+    def setup_method(self, method):
         """
             Debug information
         """
+        self.bigml = {}
+        self.bigml["method"] = method.__name__
         print("\n-------------------\nTests in: %s\n" % __name__)
 
+    def teardown_method(self):
+        """Calling generic teardown for every method
+
+        """
+        world.clear_paths()
+        print("\nEnd of tests in: %s\n-------------------\n" % __name__)
+        self.bigml = {}
+
     def test_scenario1(self):
         """
             Scenario: Successfully building dataset, model and evaluation and share them:
@@ -70,11 +72,14 @@ class TestShared(object):
                 | ../data/iris.csv   | ./scenario_sh_1/evaluation |
         """
         print(self.test_scenario1.__doc__)
+        headers = ["data", "output"]
         examples = [
             ['data/iris.csv', 'scenario_sh_1/evaluation']]
         for example in examples:
-            print("\nTesting with:\n", example)
-            test_pred.i_create_all_resources_to_evaluate_and_share(self, data=example[0], output=example[1])
+            example = dict(zip(headers, example))
+            show_method(self, self.bigml["method"], example)
+            test_pred.i_create_all_resources_to_evaluate_and_share(
+                self, data=example["data"], output=example["output"])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset_shared(self)
             test_pred.i_check_create_model_shared(self)
