@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 #!/usr/bin/env python
+#pylint: disable=locally-disabled,line-too-long,attribute-defined-outside-init
 #
-# Copyright 2017-2022 BigML
+# Copyright 2017-2023 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -20,10 +21,8 @@
 
 """
 
-
-
 from bigmler.tests.world import (world, common_setup_module,
-                                 common_teardown_module, teardown_class)
+                                 common_teardown_module, show_method)
 
 
 import bigmler.tests.basic_tst_prediction_steps as test_pred
@@ -42,21 +41,25 @@ def teardown_module():
     """
     common_teardown_module()
 
-class TestRetrain(object):
+class TestRetrain:
+    """Testing retrain command"""
 
-    def teardown(self):
-        """Calling generic teardown for every method
-
-        """
-        print("\nEnd of tests in: %s\n-------------------\n" % __name__)
-        teardown_class()
-
-    def setup(self):
+    def setup_method(self, method):
         """
             Debug information
         """
+        self.bigml = {}
+        self.bigml["method"] = method.__name__
         print("\n-------------------\nTests in: %s\n" % __name__)
 
+    def teardown_method(self):
+        """Calling generic teardown for every method
+
+        """
+        world.clear_paths()
+        print("\nEnd of tests in: %s\n-------------------\n" % __name__)
+        self.bigml = {}
+
     def test_scenario1(self):
         """
             Scenario: Successfully retraining a balanced model
@@ -70,26 +73,28 @@ class TestRetrain(object):
                 And I check that the model has been created
                 Then I check that the model has doubled its rows
                 And I check that the model is balanced
-
-                Examples:
-                |data |output_dir  | output_dir_ret
-                |../data/iris.csv | ./scenario_rt_1 |./scenario_rt_1b |
         """
         print(self.test_scenario1.__doc__)
+        headers = ["data", "output_dir", "output_dir_ret"]
         examples = [
             ['data/iris.csv', 'scenario_rt_1', 'scenario_rt_1b'],
             ['https://static.bigml.com/csv/iris.csv', 'scenario_rt_1c',
              'scenario_rt_1d']]
         for example in examples:
-            print("\nTesting with:\n", example)
-            test_pred.i_create_balanced_model(self, data=example[0], output_dir=example[1])
+            example = dict(zip(headers, example))
+            show_method(self, self.bigml["method"], example)
+            test_pred.i_create_balanced_model(
+                self, data=example["data"], output_dir=example["output_dir"])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset(self, suffix=None)
             test_pred.i_check_create_model(self)
-            test_pred.i_retrain_model(self, data=example[0], output_dir=example[2])
-            if not example[0].startswith("https"):
+            test_pred.i_retrain_model(
+                self, data=example["data"],
+                output_dir=example["output_dir_ret"])
+            if not example["data"].startswith("https"):
                 test_pred.i_check_create_source(self)
-            execute_steps.i_check_create_execution(self, number_of_executions=2)
+            execute_steps.i_check_create_execution(
+                self, number_of_executions=2)
             test_pred.i_check_create_model_in_execution(self)
             test_pred.i_check_model_double(self)
             test_pred.i_check_model_is_balanced(self)
@@ -113,21 +118,27 @@ class TestRetrain(object):
                 |../data/iris.csv | ./scenario_rt_2 |./scenario_rt_2b |
         """
         print(self.test_scenario2.__doc__)
+        headers = ["data", "output_dir", "output_dir_ret"]
         examples = [
             ['data/iris.csv', 'scenario_rt_2', 'scenario_rt_2b'],
             ['https://static.bigml.com/csv/iris.csv', 'scenario_rt_2c',
              'scenario_rt_2d']]
         for example in examples:
-            print("\nTesting with:\n", example)
-            test_pred.i_create_balanced_model_from_sample(self, data=example[0], output_dir=example[1])
+            example = dict(zip(headers, example))
+            show_method(self, self.bigml["method"], example)
+            test_pred.i_create_balanced_model_from_sample(
+                self, data=example["data"], output_dir=example["output_dir"])
             test_pred.i_check_create_source(self)
             test_pred.i_check_create_dataset(self, suffix=None)
             test_pred.i_check_create_dataset(self, suffix='gen ')
             test_pred.i_check_create_model(self)
-            test_pred.i_retrain_model(self, data=example[0], output_dir=example[2])
-            if not example[0].startswith("https"):
+            test_pred.i_retrain_model(
+                self, data=example["data"],
+                output_dir=example["output_dir_ret"])
+            if not example["data"].startswith("https"):
                 test_pred.i_check_create_source(self)
-            execute_steps.i_check_create_execution(self, number_of_executions=2)
+            execute_steps.i_check_create_execution(
+                self, number_of_executions=2)
             test_pred.i_check_create_model_in_execution(self)
             test_pred.i_check_model_double(self)
             test_pred.i_check_model_is_balanced(self)
